Module: CommitCommentTools

Defined in:
lib/commit-comment-tools/version.rb,
lib/commit-comment-tools/entry.rb,
lib/commit-comment-tools/generator.rb,
lib/commit-comment-tools/generator/csv.rb,
lib/commit-comment-tools/report-parser.rb,
lib/commit-comment-tools/generator/graph.rb,
lib/commit-comment-tools/repository-stats.rb,
lib/commit-comment-tools/report-normalizer.rb,
lib/commit-comment-tools/repository-loader.rb

Overview

Copyright © 2013 Haruka Yoshihara <[email protected]>

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <www.gnu.org/licenses/>.

Defined Under Namespace

Modules: Generator Classes: Commit, Entry, ReportNormlizer, ReportParser, RepositoryLoader, RepositoryStats

Constant Summary collapse

VERSION =
"0.0.1"